@@ -7,9 +7,9 @@ class HistoryExport:
         'id': None,     # int64 - History Export ID
         'start_at': None,     # date-time - Start date/time of export range.
         'end_at': None,     # date-time - End date/time of export range.
-        'status': None,     # string - Status of export.  Will be: `building` or `ready`
+        'status': None,     # string - Status of export.  Will be: `building`, `ready`, or `failed`
         'query_action': None,     # string - Filter results by this this action type. Valid values: `create`, `read`, `update`, `destroy`, `move`, `login`, `failedlogin`, `copy`, `user_create`, `user_update`, `user_destroy`, `group_create`, `group_update`, `group_destroy`, `permission_create`, `permission_destroy`, `api_key_create`, `api_key_update`, `api_key_destroy`
-        'query_interface': None,     # string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`
+        'query_interface': None,     # string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`, `office`
         'query_user_id': None,     # string - Return results that are actions performed by the user indiciated by this User ID
         'query_file_id': None,     # string - Return results that are file actions related to the file indicated by this File ID
         'query_parent_id': None,     # string - Return results that are file actions inside the parent folder specified by this folder ID
@@ -19,7 +19,7 @@ class HistoryExport:
         'query_destination': None,     # string - Return results that are file moves with this path as destination.
         'query_ip': None,     # string - Filter results by this IP address.
         'query_username': None,     # string - Filter results by this username.
-        'query_failure_type': None,     # string - If searching for Histories about login failures, this parameter restricts results to failures of this specific type.  Valid values: `expired_trial`, `account_overdue`, `locked_out`, `ip_mismatch`, `password_mismatch`, `site_mismatch`, `username_not_found`, `none`, `no_ftp_permission`, `no_web_permission`, `no_directory`, `errno_enoent`, `no_sftp_permission`, `no_dav_permission`, `no_restapi_permission`, `key_mismatch`, `region_mismatch`, `expired_access`, `desktop_ip_mismatch`, `desktop_api_key_not_used_quickly_enough`, `disabled`
+        'query_failure_type': None,     # string - If searching for Histories about login failures, this parameter restricts results to failures of this specific type.  Valid values: `expired_trial`, `account_overdue`, `locked_out`, `ip_mismatch`, `password_mismatch`, `site_mismatch`, `username_not_found`, `none`, `no_ftp_permission`, `no_web_permission`, `no_directory`, `errno_enoent`, `no_sftp_permission`, `no_dav_permission`, `no_restapi_permission`, `key_mismatch`, `region_mismatch`, `expired_access`, `desktop_ip_mismatch`, `desktop_api_key_not_used_quickly_enough`, `disabled`, `country_mismatch`
         'query_target_id': None,     # string - If searching for Histories about specific objects (such as Users, or API Keys), this paremeter restricts results to objects that match this ID.
         'query_target_name': None,     # string - If searching for Histories about Users, Groups or other objects with names, this parameter restricts results to objects with this name/username.
         'query_target_permission': None,     # string - If searching for Histories about Permisisons, this parameter restricts results to permissions of this level.
@@ -31,7 +31,11 @@ class HistoryExport:
         'user_id': None,     # int64 - User ID.  Provide a value of `0` to operate the current session's user.
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -52,9 +56,11 @@ class HistoryExport:
 
 # Parameters:
 #   id (required) - int64 - History Export ID.
-def find(id, params = {}, options = {}):
+def find(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -63,7 +69,7 @@ def find(id, params = {}, options = {}):
     response, options = Api.send_request("GET", "/history_exports/{id}".format(id=params['id']), params, options)
     return HistoryExport(response.data, options)
 
-def get(id, params = {}, options = {}):
+def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
@@ -71,7 +77,7 @@ def get(id, params = {}, options = {}):
 #   start_at - string - Start date/time of export range.
 #   end_at - string - End date/time of export range.
 #   query_action - string - Filter results by this this action type. Valid values: `create`, `read`, `update`, `destroy`, `move`, `login`, `failedlogin`, `copy`, `user_create`, `user_update`, `user_destroy`, `group_create`, `group_update`, `group_destroy`, `permission_create`, `permission_destroy`, `api_key_create`, `api_key_update`, `api_key_destroy`
-#   query_interface - string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`
+#   query_interface - string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`, `office`
 #   query_user_id - string - Return results that are actions performed by the user indiciated by this User ID
 #   query_file_id - string - Return results that are file actions related to the file indicated by this File ID
 #   query_parent_id - string - Return results that are file actions inside the parent folder specified by this folder ID
@@ -81,7 +87,7 @@ def get(id, params = {}, options = {}):
 #   query_destination - string - Return results that are file moves with this path as destination.
 #   query_ip - string - Filter results by this IP address.
 #   query_username - string - Filter results by this username.
-#   query_failure_type - string - If searching for Histories about login failures, this parameter restricts results to failures of this specific type.  Valid values: `expired_trial`, `account_overdue`, `locked_out`, `ip_mismatch`, `password_mismatch`, `site_mismatch`, `username_not_found`, `none`, `no_ftp_permission`, `no_web_permission`, `no_directory`, `errno_enoent`, `no_sftp_permission`, `no_dav_permission`, `no_restapi_permission`, `key_mismatch`, `region_mismatch`, `expired_access`, `desktop_ip_mismatch`, `desktop_api_key_not_used_quickly_enough`, `disabled`
+#   query_failure_type - string - If searching for Histories about login failures, this parameter restricts results to failures of this specific type.  Valid values: `expired_trial`, `account_overdue`, `locked_out`, `ip_mismatch`, `password_mismatch`, `site_mismatch`, `username_not_found`, `none`, `no_ftp_permission`, `no_web_permission`, `no_directory`, `errno_enoent`, `no_sftp_permission`, `no_dav_permission`, `no_restapi_permission`, `key_mismatch`, `region_mismatch`, `expired_access`, `desktop_ip_mismatch`, `desktop_api_key_not_used_quickly_enough`, `disabled`, `country_mismatch`
 #   query_target_id - string - If searching for Histories about specific objects (such as Users, or API Keys), this paremeter restricts results to objects that match this ID.
 #   query_target_name - string - If searching for Histories about Users, Groups or other objects with names, this parameter restricts results to objects with this name/username.
 #   query_target_permission - string - If searching for Histories about Permisisons, this parameter restricts results to permissions of this level.
@@ -89,7 +95,7 @@ def get(id, params = {}, options = {}):
 #   query_target_username - string - If searching for Histories about API keys, this parameter restricts results to API keys created by/for this username.
 #   query_target_platform - string - If searching for Histories about API keys, this parameter restricts results to API keys associated with this platform.
 #   query_target_permission_set - string - If searching for Histories about API keys, this parameter restricts results to API keys with this permission set.
-def create(params = {}, options = {}):
+def create(params = None, options = None):
     if "user_id" in params and not isinstance(params["user_id"], int):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
     if "start_at" in params and not isinstance(params["start_at"], str):
